==> cscec5b-sync-api-3.0.1-20230314.025555-29-sources.jar: com/ejianc/business/sync/vo/CalculateVO.java <==
package com.ejianc.business.sync.vo;

import java.util.ArrayList;
import java.util.List;

public class CalculateVO {
    private String pkId;//主键 VARCHAR2(100)
    private String dbegindate;//本次计租日 CHAR(10)
    private String htflh;//合同分录号 VARCHAR2(30)
    private String pkContract;//合同 CHAR(20)
    private Integer nflag;//NC是否加截 interger 默认为0

    // 子表
    private List<CalculateSettleVO> settleList = new ArrayList<>();

    // 扣款表
    private List<CalculateDetailVO> detailList = new ArrayList<>();

    public String getPkId() {
        return pkId;
    }

    public void setPkId(String pkId) {
        this.pkId = pkId;
    }

    public String getDbegindate() {
        return dbegindate;
    }

    public void setDbegindate(String dbegindate) {
        this.dbegindate = dbegindate;
    }

    public String getHtflh() {
        return htflh;
    }

    public void setHtflh(String htflh) {
        this.htflh = htflh;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Integer getNflag() {
        return nflag;
    }

    public void setNflag(Integer nflag) {
        this.nflag = nflag;
    }

    public List<CalculateSettleVO> getSettleList() {
        return settleList;
    }

    public void setSettleList(List<CalculateSettleVO> settleList) {
        this.settleList = settleList;
    }

    public List<CalculateDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CalculateDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> cscec5b-sync-api-3.0.1-20231120.091858-56-sources.jar: com/ejianc/business/sync/vo/CalculateVO.java <==
package com.ejianc.business.sync.vo;

import java.util.ArrayList;
import java.util.List;

public class CalculateVO {
    private String pkId;//主键 VARCHAR2(100)
    private String dbegindate;//本次计租日 CHAR(10)
    private String htflh;//合同分录号 VARCHAR2(30)
    private String pkContract;//合同 CHAR(20)
    private Integer nflag;//NC是否加截 interger 默认为0
    private String vurl;//轻量化地址 VARCHAR2(100)
    private String ts;

    // 子表
    private List<CalculateSettleVO> settleList = new ArrayList<>();

    // 扣款表
    private List<CalculateDetailVO> detailList = new ArrayList<>();

    public String getPkId() {
        return pkId;
    }

    public void setPkId(String pkId) {
        this.pkId = pkId;
    }

    public String getDbegindate() {
        return dbegindate;
    }

    public void setDbegindate(String dbegindate) {
        this.dbegindate = dbegindate;
    }

    public String getHtflh() {
        return htflh;
    }

    public void setHtflh(String htflh) {
        this.htflh = htflh;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public Integer getNflag() {
        return nflag;
    }

    public void setNflag(Integer nflag) {
        this.nflag = nflag;
    }

    public String getVurl() {
        return vurl;
    }

    public void setVurl(String vurl) {
        this.vurl = vurl;
    }

    public String getTs() {
        return ts;
    }

    public void setTs(String ts) {
        this.ts = ts;
    }

    public List<CalculateSettleVO> getSettleList() {
        return settleList;
    }

    public void setSettleList(List<CalculateSettleVO> settleList) {
        this.settleList = settleList;
    }

    public List<CalculateDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<CalculateDetailVO> detailList) {
        this.detailList = detailList;
    }
}
